/// <reference types="node" />
import { AxiosRequestConfig, AxiosResponse } from "axios";
import { ILoginInformation, IAuthRefreshResponse, ITokenLoginInformation } from "./auth/types";
import { UsersRoutes } from "./users/index";
import { LabelsRoutes } from "./labels/index";
import { MessagesRoutes } from "./messages/index";
import { EventEmitter } from "events";
export interface IProtonmailClientOptions {
    rateLimit: boolean;
    userAgent: string;
}
export declare interface ProtonmailClient {
    on(event: "logout", listener: () => void): this;
    on(event: string, listener: Function): this;
}
export declare class ProtonmailClient extends EventEmitter {
    private axios;
    private isloggedIn_;
    private refreshingToken_;
    private accessToken_;
    private refreshToken_;
    private pmUID_;
    private rateLimiter;
    private options;
    private pmUID;
    private accessToken;
    private refreshToken;
    private users_;
    readonly users: UsersRoutes;
    private labels_;
    readonly labels: LabelsRoutes;
    private messages_;
    readonly messages: MessagesRoutes;
    readonly isLoggedIn: boolean;
    constructor(options?: Partial<IProtonmailClientOptions>);
    private createAxiosInstance;
    request<T>(config: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    loginWithToken(loginInformation: ITokenLoginInformation): Promise<IAuthRefreshResponse>;
    getTokenLoginInformation(): ITokenLoginInformation;
    login(loginInformation: ILoginInformation): Promise<void>;
    logout(): Promise<{}>;
    private authInfo;
    private auth;
    private auth2FA;
    private authRefresh;
}
